
# q-expansion of newform 171.2.e.b, downloaded from the LMFDB on 02 May 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 171
weight = 2
poly_data = [19683, -6561, 4374, -5103, 1944, -3726, 1566, -918, 810, -243, 270, -102, 58, -46, 8, -7, 2, -1, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[22386132, -23991390, 19915551, -13358682, 7446573, -6046056, 4176252, -2720628, 1698408, -870084, 460578, -208646, 98072, -54568, 26318, -10393, 2342, 13], 1436859], [[-6561, 4374, -5103, 1944, -3726, 1566, -918, 810, -243, 270, -102, 58, -46, 8, -7, 2, -1, 1], 6561], [[2410074, -3731022, 3059856, -2276667, 1473012, -1016118, 721872, -476280, 298593, -175185, 86026, -40940, 20094, -9675, 5154, -2106, 614, -154], 478953], [[7958493, -9189774, 6972885, -4858542, 2877444, -2125899, 1606446, -954504, 615114, -316854, 155325, -77171, 31235, -19534, 9035, -3052, 881, 169], 478953], [[8448381, -4054698, 3509892, -1806705, 652104, -1111023, 437427, -362421, 182376, -54450, 42761, -1054, 6804, -4503, 1026, -291, -641, 205], 478953], [[-74493594, 60149061, -48102336, 31671891, -15950196, 15315939, -9340245, 6163128, -3836889, 1684485, -977181, 378392, -179981, 120205, -45182, 18817, -2024, -1441], 2873718], [[17445699, -1491534, -3297267, 4189320, -4724811, 407241, -1597374, 998487, -732969, 674469, -265128, 215189, -79985, 32092, -26123, 10606, -7913, 1604], 2873718], [[26742636, -21135168, 16003737, -10538667, 4947399, -5118903, 3182355, -2014875, 1293327, -525114, 304746, -115897, 52285, -39209, 14113, -4958, -269, 938], 1436859], [[21047688, -15612993, 8385687, -6274260, 1858059, -2919780, 1749978, -862812, 655803, -138465, 107787, -23351, 2804, -17401, 665, -217, -1720, 1213], 1436859], [[13122, 435213, -396576, 355995, -240894, 129141, -112455, 69660, -47547, 29421, -14421, 8302, -3349, 1673, -934, 407, -190, 37], 39366], [[3004938, 314928, -1909251, 1640736, -1520613, 602829, -558414, 450900, -275868, 216657, -103125, 61348, -29350, 11231, -7486, 3494, -1693, 505], 478953], [[-37450188, 30847635, -37836558, 26946513, -16714188, 12930165, -7392195, 5743224, -3433401, 1919007, -1108113, 471794, -262403, 114625, -57350, 27601, -8648, 3041], 2873718], [[14257053, -11475189, 13248117, -9174951, 5331987, -4763556, 2497095, -2117745, 1209870, -672408, 416649, -155251, 99736, -42473, 20839, -11489, 2545, -1141], 957906], [[3978153, -3256443, 1203822, -706887, -35775, -218160, 242298, -17496, 53604, 22419, -18413, 7487, -11446, -634, -1237, 1169, -641, 570], 478953], [[25791291, -11125269, 2452356, 662175, -3193668, -226206, -356508, 631071, -364149, 542799, -257163, 177652, -95365, 23669, -21805, 11576, -6847, 3208], 1436859], [[7582329, 5010417, -13733145, 9935541, -9177165, 4498038, -3367629, 2748087, -1563354, 1182114, -596527, 323071, -165362, 58627, -40247, 18025, -8491, 2931], 957906]]

hecke_ring_character_values = [[20, [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0]], [154, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]]]
aps_data = [[0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 1, 0, 0, 0, 0, 0, 0], [0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0], [0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0], [0, -1, -1, 0, 1, 0, 0, 0, 0, 1, 0, 0, 1, 0, 0, 1, -1, 0], [2, 0, 1, 0, -1, 0, 0, -1, 1, 0, -2, -1, 0, 1, 0, -1, 0, 1], [0, 1, -1, 1, -1, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, -1, -1, 0], [-1, -1, -1, 1, -1, 2, 1, 1, 0, 1, 1, 0, 0, 1, 0, 0, -2, 0], [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, -2, 1, -1, 2, 1, -5, -1, -1, 1, -2, 0, 1, -2, 1, 1, 2, 2], [1, -1, 0, -2, 0, 2, -2, 2, 0, 1, -3, 0, 1, -2, 2, 2, 1, 0], [0, 1, 1, 0, 1, -1, -1, -1, 0, 0, 0, 0, 1, 1, 1, 1, -1, -1], [3, 0, 0, 0, 0, -1, 0, -2, 0, 0, -2, -1, 0, -1, -1, -2, 1, 1], [0, -1, 2, 1, 1, 2, -2, 0, 0, -1, 1, 0, 2, 0, 0, 2, 1, 0], [-1, 2, 1, -1, -1, 1, -2, 1, 1, 0, -1, -1, 0, -1, 2, -2, 3, 1], [0, 0, -1, 0, 1, 0, 0, 0, 0, -1, 0, 0, -1, 0, 0, 2, 0, 0], [-5, 0, 0, 0, -1, 0, 1, 1, 0, 1, 1, 3, -1, 0, 1, -1, 0, -1], [0, 1, -3, -1, -3, -2, 6, 1, 1, 0, 6, 0, -3, 2, -1, -3, -1, -2], [1, 1, 2, 0, -2, 0, 0, 0, 2, -1, -1, -2, -1, 0, 0, 1, 1, 0], [0, 0, -1, 2, -3, 2, 4, -1, 2, -2, 1, 0, -1, 1, 1, -1, 0, -1], [-3, 0, 2, 0, 2, -3, 0, -1, 0, -2, -1, -1, 0, 0, -1, -1, 3, 1], [-4, 1, -1, -1, 0, 2, 0, 1, 0, 0, 1, 2, 1, -1, 2, 2, -2, -2], [2, -1, -3, 2, 3, -2, 4, -2, -4, 0, 2, 4, 0, 2, -4, -1, -3, -2], [1, 3, 1, 3, -1, -3, 1, 0, 2, -3, 0, -2, -3, 0, -1, -3, 0, -1], [-7, -1, 0, 1, 0, 2, -3, 1, 0, 0, 1, 0, 0, -1, 2, 4, -2, -2], [-3, -1, 0, -2, 0, 2, 1, -2, -2, -2, 4, 2, -2, 2, -1, -1, 1, 1], [0, -3, 0, -3, 0, 3, 0, 0, -2, 0, 0, 2, 0, 0, 0, 3, 0, 0], [0, 1, -3, 1, -2, 0, 9, 3, 0, 1, 7, 0, -3, 3, -3, -3, -1, -3], [2, -6, -6, 6, -3, 3, 6, 1, 0, 3, 1, 3, 3, 2, -1, -2, -3, 1], [-3, 2, 5, -2, 5, -1, -5, -1, 0, -5, -1, -1, 0, -2, 1, 4, 1, -1], [0, -3, 2, 0, 1, 3, -7, -2, 2, -1, -1, 0, 2, -4, 2, 2, 3, 4], [-4, 1, -1, -1, -3, -1, 2, 3, 0, 3, 3, -1, -2, 0, 3, -1, 1, -3], [0, 1, -3, -1, -2, -2, 9, 3, -3, 1, 5, 0, -3, 2, -3, -3, -1, -2], [3, -2, 1, -1, -1, 1, -3, 2, 2, 3, -6, -2, 3, -2, 3, 1, -1, 1], [0, -3, 3, -4, 3, -1, -5, 0, 1, 0, -2, 0, 3, -3, 0, 3, 3, 3], [0, -1, 2, 1, -2, 2, -1, -1, 3, -4, 2, 0, 2, -2, 1, 2, 1, 2], [-3, 2, -1, 3, 1, -3, 1, 1, -5, -1, 4, 5, -1, -1, -1, 0, -1, -2], [0, 2, -2, 2, -1, 0, 2, 0, 2, 1, 6, 0, -2, 0, 0, -2, -2, 0], [-2, -2, 3, 2, 2, 1, -9, -1, 0, -2, -1, -5, -1, -2, 1, 7, -1, -1], [0, 2, 2, -2, 1, -4, -2, -1, -2, -1, 4, 0, 2, 1, 1, 2, -2, -1], [5, -3, -3, 3, 3, -3, 5, -2, -4, 2, 0, 4, 2, 2, -5, -5, -6, -3], [-8, 5, 2, -5, 3, -4, -2, 1, 0, -3, 1, 1, 1, 0, 1, 4, 4, -1], [-1, -1, 1, 1, 1, -2, -1, -4, 0, -1, -4, -3, 0, 1, -5, -3, 2, 5], [-3, 0, -1, -3, 1, 3, -2, 4, 0, -4, 1, 0, -4, -4, 2, 2, 3, -2], [0, 7, -1, 2, -2, -5, 1, 1, 6, -1, 3, 0, -1, 5, -1, -1, -7, -5], [-3, 4, 4, -4, 0, -5, -3, -1, 0, 0, -1, -5, -4, 0, -1, -2, 5, 1], [5, -1, -2, 1, -3, -1, 1, -1, 0, 3, -1, 2, -1, 1, -2, -3, 1, 2], [0, -5, 0, 0, -1, 5, 4, 1, 0, -1, 5, 0, 0, -1, -1, 0, 5, 1], [2, 4, 2, 3, -2, -3, 5, -1, 3, -6, 3, -3, -6, 1, -5, -3, 1, -4], [3, -2, -1, -1, 1, 1, -2, 0, -4, 4, -5, 4, 4, 0, 2, 2, -1, 2], [0, -1, -3, 7, -8, 8, 11, 3, 5, -5, 1, 0, -3, 0, -3, -3, 1, 0], [-7, 2, 7, -2, 6, 2, -11, 1, 0, -6, 1, -1, -1, -2, 3, 11, -2, -3], [0, 1, 2, -1, 5, -2, -9, -2, -1, 3, -7, 0, 2, 1, 2, 2, -1, -1], [4, 6, -1, 2, 1, -2, -1, -1, 1, 5, -5, -1, 5, 1, 1, -3, 4, 2], [1, 6, -3, -6, -2, 0, 6, 4, 0, 2, 4, -5, 1, 1, 3, -1, 0, -3], [0, 3, -2, 0, 1, -3, 5, 3, -1, 3, 3, 0, -2, 4, -3, -2, -3, -4], [-2, 3, 2, 3, -2, -3, 1, -1, -1, 0, 3, 1, 0, 1, -1, 1, 0, 0], [4, 0, 2, 0, 4, 0, 1, -3, 0, -4, -3, -1, 2, 0, -3, -2, 0, 3], [-1, 1, -4, -1, -4, 0, -2, 3, 0, 4, 3, -2, 0, 3, 0, 5, 0, 0], [-1, 5, -2, 4, 2, -4, 2, -1, -3, -5, 3, 3, -5, 1, -2, -5, 1, -1], [4, -3, -2, -3, 2, 3, -2, 3, 1, 0, -6, -1, 0, -3, 2, 9, 0, -1], [0, 1, -6, 3, -1, 2, 6, 3, -6, 5, 5, 0, -6, 3, -3, -6, -1, -3], [0, 5, -2, 4, 2, -1, 4, 2, -4, 4, 10, 0, -2, 4, -2, -2, -5, -4], [0, 2, 2, -2, 4, -4, -1, 2, 0, -4, 2, 0, 2, -2, 4, 5, 4, -4], [0, 0, -3, 6, -6, 6, 6, 2, 3, -3, 0, 0, -3, 1, -2, -3, 0, -1], [-10, 5, 2, 3, -2, -3, -3, 6, 4, -4, 7, -4, -4, -6, 3, 6, 2, -3], [13, 6, 2, 0, -2, 0, 3, -5, 5, -3, -10, -5, -3, 5, -3, -8, 6, 2], [7, -3, 1, -1, -1, 1, -4, -1, 7, 4, -11, -7, 4, 1, 4, -4, -2, 5], [0, -1, -2, -1, 2, 0, 0, 1, -7, 4, -6, 0, -2, 2, -1, -2, 1, -2], [0, 0, 0, 0, 1, 0, -6, -3, 1, 1, -10, 0, 0, -4, 3, 0, 0, 4], [3, 4, 1, 1, -1, -1, 3, -3, 1, -5, 0, -1, -5, 3, -3, -7, 3, 0], [-5, -2, -3, -1, 3, 1, -3, 0, 8, 3, 2, -8, 3, 0, 3, -1, -1, 3], [9, 3, 10, -3, 3, -9, -6, -4, 0, -3, -4, -8, -7, 0, -4, -5, 9, 4], [3, 0, 2, 6, -2, -6, 2, -4, 2, 4, -1, -2, 4, 4, -2, -6, -6, 2], [0, 3, 5, -6, 9, -9, -1, -2, -8, 4, -2, 0, 5, 2, 2, 5, -3, -2], [3, -7, -1, 7, 2, 3, -4, -1, 0, -2, -1, -3, 3, -2, 1, 6, -3, -1], [0, 6, -1, 6, -3, 0, 2, -2, 6, -2, -9, 0, -1, 0, 2, -1, -6, 0], [6, 3, 1, 0, -1, 0, 1, 1, -3, -2, -5, 3, -2, -1, -1, 4, 3, -2], [-1, -2, -2, 2, 1, 0, 0, -6, 0, -1, -6, 3, 3, -3, -3, -3, 0, 3], [0, -5, -2, -7, 2, -2, -1, -3, 3, 4, 2, 0, -2, 0, 3, -2, 5, 0], [0, -6, 2, -8, 5, -2, -6, -4, -5, 3, -6, 0, 2, -5, 4, 2, 6, 5], [0, -4, 3, -8, 2, -4, -12, -2, -1, -1, -2, 0, 3, -3, 2, 3, 4, 3], [-6, -3, -5, 2, 5, -2, -1, 2, -4, 5, 5, 4, 5, -2, 1, 7, -5, -1], [-1, 0, 0, 0, 0, 3, -4, -3, 0, 0, -3, 1, 0, 0, -3, 1, -3, 3], [4, 6, 4, -6, -2, -4, 5, 2, 0, 2, 2, 3, -6, 1, 1, -9, 4, -1], [-8, -7, 1, -10, -1, 10, -6, 6, -10, 1, 2, 10, 1, -6, 6, 6, 3, 0], [-16, -3, 5, -6, -5, 6, -7, 5, -7, 5, 9, 7, 5, -5, 7, 6, 3, 2], [-1, -2, 4, 2, -2, -5, -9, 2, 0, 2, 2, -5, -6, -1, 3, 5, 5, -3], [2, 2, 1, 2, -1, -2, 6, -3, 5, -8, 4, -5, -8, 3, -6, -3, 0, -3], [12, -7, -2, -5, 2, 5, 2, -5, -1, 3, -10, 1, 3, 5, -2, -2, -2, 3], [0, -1, -2, -8, -1, -7, 10, -2, -6, 1, 11, 0, -2, 2, 2, -2, 1, -2], [6, 1, -2, -1, -1, -2, 3, 3, 0, 1, 3, -1, 1, 0, 3, 1, 2, -3], [-3, -6, -8, 0, 8, 0, 1, -2, -8, 10, 4, 8, 10, 2, -1, -2, -6, 1], [10, -8, -3, 8, 4, 3, 4, -9, 0, -4, -9, 7, 7, -6, -3, -6, -3, 3], [0, 3, -1, -6, 3, -9, 5, 3, -8, 4, 6, 0, -1, 1, -3, -1, -3, -1], [0, 1, 2, 7, -2, 6, 4, 3, 4, -4, -2, 0, 2, 3, -3, 2, -1, -3], [-2, 3, -2, -3, 2, 3, -4, -5, 0, -2, -5, 5, 4, -4, -1, 3, -3, 1], [0, -3, -5, 3, -6, 6, 3, 5, -1, -1, 23, 0, -5, 0, -5, -5, 3, 0], [-8, 0, -7, 0, -9, 6, 11, 5, 0, 9, 5, -5, -2, 2, 3, -8, -6, -3], [0, -5, 1, 5, 4, 2, -1, 0, 0, -4, 0, 8, 3, 0, 0, 4, -2, 0], [0, 7, 2, -7, 7, -6, -2, -1, 0, -7, -1, 8, 5, 1, -2, 6, 6, 2], [3, -3, 2, -2, -2, 2, 4, -5, 7, -5, 1, -7, -5, 5, -4, -7, -1, 1], [7, -1, -1, 1, 0, 5, -3, 0, 0, 0, 0, -6, 1, 4, -4, 4, -5, 4], [0, -2, -5, -4, -4, -2, 12, 1, 6, 1, 0, 0, -5, 5, -1, -5, 2, -5], [18, 6, 5, 0, -5, 0, 1, -1, 7, -6, -17, -7, -6, 1, -1, -4, 6, 0], [0, -3, 4, -6, 9, -3, -6, -2, -4, 5, -3, 0, 4, -4, 2, 4, 3, 4], [-4, -2, 2, 2, 11, 3, -12, -4, 0, -11, -4, 1, 9, -5, 1, 17, -3, -1], [-11, -1, -2, 4, 2, -4, -2, 4, 2, -2, 9, -2, -2, -4, 2, 9, -5, -2], [0, 6, 9, -6, 8, -9, -17, -4, 0, -8, -4, 1, -1, -7, 3, 12, 9, -3], [0, -3, -2, 0, -3, 3, -2, -1, 2, -1, -9, 0, -2, -9, 1, -2, 3, 9], [3, 7, 2, 4, -2, -4, 3, -3, 13, -4, 0, -13, -4, 3, -3, 0, 3, 0], [0, 0, 2, -9, 3, -9, 3, 2, 4, 1, -8, 0, 2, -2, -2, 2, 0, 2], [-1, 3, -2, -3, -9, -1, 2, 1, 0, 9, 1, 1, -7, 2, -1, -8, 1, 1], [0, 2, 7, -2, 9, -4, -11, 0, -10, 2, 3, 0, 7, -4, 0, 7, -2, 4], [0, 2, -1, -2, 1, 2, 4, -2, -4, -2, 4, 4, -2, 2, -4, 3, 4, -2], [8, 3, 4, -3, 3, -6, -3, 1, 0, -3, 1, 2, -1, 5, -4, 3, 6, 4], [11, -3, 2, -6, -2, 6, 1, -3, -1, 1, -10, 1, 1, 3, -1, -12, 3, 2], [0, -7, 1, -4, 0, 3, -4, 1, 1, -1, -5, 0, 1, -4, -1, 1, 7, 4], [3, -13, -4, 13, -2, 8, 3, -3, 0, 2, -3, 6, 2, -3, 0, -4, -8, 0], [0, -6, -2, 3, -3, 9, -1, 1, -7, -1, 10, 0, -2, -2, -1, -2, 6, 2], [3, 6, 4, 6, -4, -6, 0, 2, -2, -9, -3, 2, -9, -2, 0, 4, 0, -2], [0, 7, -3, 3, -2, -4, 10, 3, -11, 1, -1, 0, -3, 0, -3, -3, -7, 0], [-2, 6, 2, 5, -2, -5, -3, 3, 9, -2, -1, -9, -2, -3, 3, 1, 1, 0], [-8, 4, 5, 2, -5, -2, -3, 3, -1, -4, 5, 1, -4, -3, 3, 4, 2, 0], [0, 1, 1, -1, -9, 1, 5, 4, 0, 9, 4, -7, -10, 7, -3, -11, -1, 3], [6, -7, -2, 3, 2, -3, 6, -3, -13, 5, 0, 13, 5, 3, -6, -5, -10, -3], [-13, -2, 2, 2, 4, 1, 0, 1, 0, -4, 1, 13, 2, -4, 5, 3, -1, -5], [8, 2, -6, 1, 6, -1, -2, 4, -8, 1, -10, 8, 1, -4, 2, -1, 1, -2], [-10, 5, -4, -5, -2, 5, 4, 8, 0, 2, 8, 9, 2, 1, 7, 6, -5, -7], [-3, 0, -9, -3, 9, 3, -1, 2, -4, 5, 2, 4, 5, -2, 1, 1, 3, -1], [0, -8, 2, 0, 2, 8, -11, 0, 7, 0, -5, 0, 2, -3, 0, 2, 8, 3], [-5, 7, 0, -7, 3, 3, -5, 8, 0, -3, 8, 2, 3, -2, 10, 16, -3, -10], [0, 11, -1, 13, -6, 2, -4, 2, -1, -5, -15, 0, -1, -1, -2, -1, -11, 1], [0, 11, 9, -2, 8, -13, -9, -1, -5, -1, -3, 0, 9, 4, 1, 9, -11, -4], [-3, 2, -9, -2, -2, -4, 20, 0, 0, 2, 0, 5, 7, 3, -3, -13, 4, 3], [0, -6, 7, -9, 7, -3, -3, 0, -8, 0, 13, 0, 7, -2, 0, 7, 6, 2], [0, 1, -2, 6, -4, 5, 2, 3, -1, -2, -2, 0, -2, 6, -3, -2, -1, -6], [-4, -3, -6, 3, -5, 6, 17, 2, 0, 5, 2, -6, 1, 6, -4, -14, -6, 4], [0, 4, -4, -3, 1, -7, 6, 1, -4, 5, 12, 0, -4, 5, -1, -4, -4, -5], [0, 1, 11, -4, 4, -5, -7, -3, -2, -7, 11, 0, 11, -3, 3, 11, -1, 3], [6, 8, 2, -8, -4, -4, 7, 3, 0, 4, 3, -6, -6, 5, -2, -10, 4, 2], [-9, 5, -2, -5, -6, 2, 4, 8, 0, 6, 8, 2, -4, 4, 4, 0, -2, -4], [12, 7, -6, 5, 6, -5, 9, -3, -3, -3, -3, 3, -3, 3, -9, -6, 2, -6], [0, 4, 1, -3, 0, -7, -11, -3, 1, -1, -14, 0, 1, -6, 3, 1, -4, 6], [19, -15, 2, 15, 3, 3, -15, -12, 0, -3, -12, -2, 1, -2, -10, 4, -3, 10], [-15, -2, -7, 2, -4, 16, 7, 11, 0, 4, 11, 2, 3, 7, 4, 7, -16, -4], [6, -5, -1, -4, 1, 4, 3, -1, 5, 4, -3, -5, 4, 1, -3, 2, -1, -2], [0, -6, -6, -5, 6, 5, -1, 2, -2, 11, -1, 2, 11, -2, 1, -6, -1, -1], [-4, 11, 9, 4, -9, -4, -1, -3, 15, -11, 3, -15, -11, 3, 1, -14, 7, 4], [0, -9, -8, 2, -4, 11, 3, -1, -2, 4, 8, 0, -8, 1, 1, -8, 9, -1], [-1, 5, 7, -5, 0, -7, -4, -4, 0, 0, -4, 4, -7, -6, 2, -7, 7, -2], [0, -8, 5, -6, 3, 2, 0, 0, 3, -2, -17, 0, 5, -9, 0, 5, 8, 9], [10, -9, -10, 9, -8, 9, 20, -2, 0, 8, -2, 7, 2, 5, -7, -20, -9, 7], [-3, -8, -7, 8, -3, 9, 6, 0, 0, 3, 0, 15, 4, 3, -3, -2, -9, 3], [0, 8, 0, 10, -9, 2, -3, -2, 12, -9, -6, 0, 0, 2, 2, 0, -8, -2], [-15, 4, 3, -9, -3, 9, -5, 7, 1, -1, 10, -1, -1, -7, 5, 9, 13, -2], [5, 10, -1, -1, 1, 1, 0, 2, 8, -5, -5, -8, -5, -2, 0, 9, 11, -2], [13, 1, -5, -1, -9, 0, 13, -3, 0, 9, -3, -2, -4, 3, -6, -20, 0, 6], [0, -14, 0, -1, 0, 1, -1, -1, -1, 9, -1, 1, 9, 1, 1, 0, -13, 2], [-4, -7, 5, 7, 8, 0, -4, -4, 0, -8, -4, -3, 3, 1, -5, 3, 0, 5], [0, -3, 1, 9, -7, 12, -10, -6, 9, -8, 2, 0, 1, -3, 6, 1, 3, 3], [-4, 0, -1, 0, 1, 0, -4, 8, -8, -1, 0, 8, -1, -8, 4, 3, 0, -4], [-1, 18, 5, -18, -2, -6, -8, 8, 0, 2, 8, -4, -7, -2, 10, 9, 6, -10], [0, 6, -4, 9, -2, 3, 8, 2, -3, 2, 19, 0, -4, 7, -2, -4, -6, -7], [9, 8, 11, -8, 5, -13, 0, 2, 0, -5, 2, -1, -6, -3, 5, -4, 13, -5], [0, 6, 8, -3, 7, -9, -16, -7, 0, -1, -4, 0, 8, -5, 7, 8, -6, 5], [-15, -7, 0, -2, 0, 2, 5, 3, -3, -8, 20, 3, -8, -3, -5, 9, -5, -8], [-12, -1, -17, 1, -14, 8, 17, 10, 0, 14, 10, 7, 3, 5, 5, -4, -8, -5], [-5, -5, 5, -9, -5, 9, -7, 8, 0, 3, -2, 0, 3, -8, 7, 12, 4, -1]]
